@@ -263,12 +263,13 @@ class S3Connection(FileSystem):
 
 
 class GenericStreamWrapper(io.RawIOBase):
-    def __init__(self, stream, readable=None, writable=None):
+    def __init__(self, stream, readable=None, writable=None, close: bool=True):
         self._target = stream
         self._readable = readable if readable is not None else True if not hasattr(stream, "readable") else stream.readable()
         self._writable = writable if writable is not None else False if not hasattr(stream, "writable") else stream.writable()
         self._seekable = False if not hasattr(stream, "seekable") else stream.seekable()
         self._closed = False
+        self._close_orig = close
 
     def readable(self) -> bool:
         return self._readable
@@ -286,6 +287,8 @@ class GenericStreamWrapper(io.RawIOBase):
         return self._target.closed
 
     def close(self):
+        if not self._close_orig:
+            return
         self._closed = True
         if not hasattr(self._target, "close"):
             return
@@ -302,7 +305,12 @@ class GenericStreamWrapper(io.RawIOBase):
     def seek(self, __offset: int, __whence: int=None) -> int:
         if not hasattr(self._target, "seek"):
             raise NotImplementedError()
-        return self._target.seek(__offset, __whence)
+        return self._target.seek(__offset, __whence or 0)
+
+    def tell(self) -> int:
+        if not hasattr(self._target, "tell"):
+            raise NotImplementedError()
+        return self._target.tell()
 
     def flush(self) -> None:
         if not hasattr(self._target, "flush"):
@@ -314,3 +322,26 @@ class GenericStreamWrapper(io.RawIOBase):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
+
+
+class BytesIOWrapper(io.RawIOBase):
+    """
+    https://www.py4u.net/discuss/189585
+    """
+    def __init__(self, file_to_wrap, encoding: str="utf-8"):
+        self.orig_file = file_to_wrap
+        self.encoding = encoding
+        self.buffer = b''
+
+    def readinto(self, buf):
+        if not self.buffer:
+            self.buffer = self.orig_file.read(200000).encode(self.encoding, errors='ignore')
+            if not self.buffer:
+                return 0
+        length = min(len(buf), len(self.buffer))
+        buf[:length] = self.buffer[:length]
+        self.buffer = self.buffer[length:]
+        return length
+
+    def readable(self):
+        return True
