@@ -573,6 +573,8 @@ class DSLibrary(object):
             self._default_format_for_aliases(resource_name, kwargs)
         format = kwargs.pop("format", None) or file_extension
         format_options = dict(kwargs.pop("format_options", None) or {})
+        if not format:
+            format = format_options.pop("format", None)
         # detect SQL target
         if kwargs.get("sql_table"):
             # write data to an SQL table
