@@ -255,7 +255,7 @@ class ModelRunner(object):
                 # TODO don't clobber self.inputs, this should be strictly temporary
                 self.inputs[resource_name]["uri"] = f_w.name
                 self.inputs[resource_name]["format"] = "csv"
-                self.inputs[resource_name]["format_options"] = {"sep": "\t"}
+                self.inputs[resource_name]["format_options"] = {"delimiter": "\t"}
                 temp_files.append(f_w.name)
         # when capturing outputs, redirect to temporary file
         output_capture_files = {}
