@@ -74,6 +74,11 @@ class VolumeWatcher(object):
         method_path0 = f"{request['method']}:{path_parts[0]}"
         params = request.get("params", {})
         path = "/".join(path_parts[1:])
+        resource_name = params.get("resource_name")
+        if resource_name:
+            if resource_name.startswith("../") or "/../" in resource_name or resource_name.endswith("/..") or resource_name == "..":
+                raise ValueError("break-out path blocked")
+            path = os.path.join(path, resource_name)
         # read file content
         if method_path0 in ("get:resources", "get:run_data"):
             if method_path0 == "get:run_data":
