@@ -168,7 +168,7 @@ def dataframe_to_sql(dataframe, table_name: str, append: bool=False):
         return name
     if not append:
         yield "DROP TABLE IF EXISTS %s" % enquote(table_name), []
-    dtype_to_sql = {"int64": "INTEGER", "float64": "DOUBLE"}
+    dtype_to_sql = {"int64": "INTEGER", "float64": "DOUBLE PRECISION"}
     cols = list(dataframe.columns)
     types = []
     for col, dtype in zip(cols, dataframe.dtypes):
