@@ -36,7 +36,7 @@ class FileOpener(object):
         """
         if path.startswith("https://") or path.startswith("http://") or path.startswith("ftp://"):
             if mode == "rb":
-                request = urllib.request.Request(url=path, headers=kwargs.get("headers", None))
+                request = urllib.request.Request(url=path, headers=kwargs.get("headers") or {})
                 return urllib.request.urlopen(request, **kwargs)
             if mode == "r":
                 byte_stream = self.http_open(path, mode, **kwargs)
@@ -46,7 +46,7 @@ class FileOpener(object):
                 #  - set method to POST or PUT
                 #  - set any needed authentication headers in 'headers'
                 #  - path is URL plus any required arguments in the query string
-                request = urllib.request.Request(url=path, headers=kwargs.get("headers", None), method=kwargs.get("method", "POST"))
+                request = urllib.request.Request(url=path, headers=kwargs.get("headers") or {}, method=kwargs.get("method", "POST"))
                 return write_stream_with_read_on_close(mode, r_mode='rb', on_close=lambda stream: urllib.request.urlopen(request, data=stream))
             raise ValueError(f"Append mode is not supported for {path}")
 
@@ -142,15 +142,3 @@ def connect_to_filesystem(uri: str, for_write: bool=False, **kwargs):
     if not for_write:
         return FileSystemReadOnly(fs)
     return fs
-
-
-def find_url_extension(url: str) -> str:
-    """
-    Find the extension of a filename or URL.
-    """
-    url = url or ""
-    if "#" in url:
-        url = url.split("#")[0]
-    if "?" in url:
-        url = url.split("?")[0]
-    return os.path.splitext(url)[1].lower().strip(".")
