@@ -253,7 +253,7 @@ def apply_csv_read_args(sample, read_args):
         sample = sample.decode("utf-8", errors="ignore")
     sniffer = csv.Sniffer()
     try:
-        dialect = sniffer.sniff(sample)
+        dialect = sniffer.sniff(sample, delimiters=",;| \t:")
     except csv.Error:
         if not alt_delimiter_detection(sample, read_args):
             read_args["delimiter"] = "\n"
